@@ -439,12 +439,18 @@ def adjNVmatch(text5):
   #pattern2 =[{"LIKE_EMAIL":True}]
   pattern2 = [{"POS": "ADJ","OP":"+"},{"POS": "NOUN","OP":"+"}]
   matcher.add('A+N', [pattern2])
+  
+  pattern3 = [{"POS": "VERB","OP":"+"},{"POS": "ADJ","OP":"*"},{"POS": "NOUN","OP":"+"}]   # 11.11.2022 modified 
+  matcher.add('V(A)+N', [pattern3]) # like beautiful girl - like girl, beautiful girl 
 
-  pattern3 = [{"POS": "VERB","OP":"+"},{"POS": "NOUN","OP":"+"}]   # 09.10.2022 {"POS": "VERB"}
-  matcher.add('V+N', [pattern3])
+  pattern4 = [{"POS": "ADJ","OP":"*"},{"POS": "NOUN","OP":"+"},{"LOWER": "be","OP":"+"},{"POS": "VERB"}]  # 11.11.2022 modified 
+  matcher.add('(A)N+V', [pattern4]) # delicious food is recommened 
 
-  pattern4 = [{"POS": "NOUN","OP":"+"},{"LOWER": "be","OP":"+"},{"POS": "VERB"}]
-  matcher.add('N+V', [pattern4])
+  # pattern3 = [{"POS": "VERB","OP":"+"},{"POS": "NOUN","OP":"+"}]   # 09.10.2022 {"POS": "VERB"}
+  # matcher.add('V+N', [pattern3])
+
+  # pattern4 = [{"POS": "NOUN","OP":"+"},{"LOWER": "be","OP":"+"},{"POS": "VERB"}]
+  # matcher.add('N+V', [pattern4])
 
   #doc = nlp("restaurantfood be nice expensive food like nice expensive , company be recommend,address , the price-quality ration is not quite right, soon cafe be hot cool massage place, beautiful destination, I like hotel")
   doc = nlp(text5)
